#ifndef _FILTERS_FILTER_HELPER_H
#define _FILTERS_FILTER_HELPER_H

/*
 * Helper for filter module writing.
 *
 * To be included at the end of the filter source file, after having filled
 * the FILTER_* macros to sensible values.
 *
 * Also see filters/filter.h
 */

#ifndef FILTER_NAME
# error No FILTER_NAME macro defined
#endif

#define filter_init XSYM_LTX(FILTER_NAME, init)

#ifdef FILTER_CLOSE_FUNCTION
# define filter_close XSYM_LTX(FILTER_NAME, close)
#endif

#ifndef FILTER_IMPORT_FUNCTION
# define FILTER_IMPORT_FUNCTION NULL
#endif

#ifndef FILTER_EXPORT_FUNCTION
# define FILTER_EXPORT_FUNCTION NULL
#endif

static struct filter_ops my_ops;

static char *
filter_description()
{
#ifdef FILTER_DESC_HOOK
	return FILTER_DESC_HOOK();
#else
	return FILTER_DESCRIPTION;
#endif
}

struct filter_ops *
filter_init(struct abook_ops *main_ops, abook_list *args)
{
	if(main_ops)
		memcpy(&OPS_STRUCT, main_ops, sizeof(struct abook_ops));

#ifdef FILTER_INIT_HOOK
	if(args)
		FILTER_INIT_HOOK(args);
#endif

	my_ops.export = FILTER_EXPORT_FUNCTION;
	my_ops.import = FILTER_IMPORT_FUNCTION;
	my_ops.description = filter_description;

	return &my_ops;
}

#ifdef FILTER_CLOSE_FUNCTION
void filter_close()
{
	FILTER_CLOSE_FUNCTION();
}
#endif

#endif /* _FILTERS_FILTER_HELPER_H */
