
/*
 * $Id$
 *
 * (C) by abook developers
 */

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#ifdef HAVE_CONFIG_H
#	include "../config.h"
#endif
#include "../abook.h"
#include "../db_access.h"
#include "../misc.h"
#include "../xmalloc.h"

#include "filter_interface.h"
#include "filter.h"

#include "filter_misc.h" /* get_real_name() */

static void	html_export_write_head(FILE *out, int extra_column);
static void	html_export_write_tail(FILE *out);


static int
html_export_database(FILE *out, struct db_enumerator e)
{
	char *email, *str;
	int extra_column = -1;

#if 0
	if(list_is_empty())
		return 2;
#endif

	str = opt_get_value_string("extra_column");
	if(str && *str)
		extra_column = (!strcmp(str, "name") ||	!strcmp(str, "email")) ?
			-1 : field_index(str);
	free(str);
		
	html_export_write_head(out, extra_column);

	db_enumerate_items(e) {
		email = get_first_email(e.item);
		if (*email)
			fprintf(out, "<tr>\n<td>"
					"<a href=\"mailto:%s\">%s</a></td>\n",
					email,
					db_name_get(e.item));
		else
			fprintf(out, "<tr>\n<td>%s</td>\n",db_name_get(e.item));

		xfree(email);

		fprintf(out, "<td>%s</td>\n", db_email_get(e.item));
		if(extra_column >= 0)
			fprintf(out, "<td>%s</td>\n",
				safe_str(db_fget_byid(e.item, extra_column)));
		fprintf(out, "</tr>\n\n");
	}

	html_export_write_tail(out);

	return 0;
}

static void
html_export_write_head(FILE *out, int extra_column)
{
	char *realname = get_real_name();

	fprintf(out, "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.01 Transitional//EN\">\n");
	fprintf(out, "<html>\n<head>\n <title>%s's addressbook</title>",
			realname );
	fprintf(out, "\n</head>\n<body>\n");
	fprintf(out, "\n<h2>%s's addressbook</h2>\n", realname );
	fprintf(out, "<br><br>\n\n");

	fprintf(out, "<table border=\"1\" align=\"center\">\n");
	fprintf(out, "\n<tr><th>Name</th><th>E-mail address(es)</th>");
	if(extra_column >= 0) {
		fprintf(out, "<th>%s</th>", safe_str(field_name(extra_column)));
	}
	fprintf(out, "</tr>\n\n");

	free(realname);
}

static void
html_export_write_tail(FILE *out)
{
	fprintf(out, "\n</table>\n");
	fprintf(out, "\n</body>\n</html>\n");
}

/*
 * Using filter helper
 */
#define FILTER_NAME html
#define FILTER_DESCRIPTION N_("html document")
#define FILTER_EXPORT_FUNCTION html_export_database
#include "filter_helper.h"
