
/*
 * $Id$
 *
 * (C) by abook developers
 */

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#ifdef HAVE_CONFIG_H
#	include "../config.h"
#endif
#include "../abook.h"
#include "../db_access.h"
#include "../misc.h"
#include "../xmalloc.h"

#include "filter_interface.h"
#include "filter.h"

#include "filters/filter_misc.h" /* get_real_name() */


static void
text_write_address_us(FILE *out, int i) {
	fprintf(out, "\n%s", db_fget(i, ADDRESS));

   	if(db_fget(i, ADDRESS2))
		fprintf(out, "\n%s", db_fget(i, ADDRESS2));

	if(db_fget(i, CITY))
		fprintf(out, "\n%s", db_fget(i, CITY));

	if(db_fget(i, STATE) || db_fget(i, ZIP)) {
		fputc('\n', out);

		if(db_fget(i, STATE)) {
			fprintf(out, "%s", db_fget(i, STATE));
			if(db_fget(i, ZIP))
				fputc(' ', out);
		}

		if(db_fget(i, ZIP))
			fprintf(out, "%s", db_fget(i, ZIP));
	}

	if(db_fget(i, COUNTRY))
		fprintf(out, "\n%s", db_fget(i, COUNTRY));
}


static void
text_write_address_uk(FILE *out, int i) {
	int j;

	for(j = ADDRESS; j <= COUNTRY; j++)
		if(db_fget(i, j))
			fprintf(out, "\n%s", db_fget(i, j));
}

static void
text_write_address_eu(FILE *out, int i) {
	fprintf(out, "\n%s", db_fget(i, ADDRESS));

   	if(db_fget(i, ADDRESS2))
		fprintf(out, "\n%s", db_fget(i, ADDRESS2));

	if(db_fget(i, ZIP) || db_fget(i, CITY)) {
		fputc('\n', out);

		if(db_fget(i, ZIP)) {
			fprintf(out, "%s", db_fget(i, ZIP));
			if(db_fget(i, CITY))
				fputc(' ', out);
		}

		fprintf(out, "%s", safe_str(db_fget(i, CITY)));
	}

	if(db_fget(i, STATE))
		fprintf(out, "\n%s", db_fget(i, STATE));

	if(db_fget(i, COUNTRY))
		fprintf(out, "\n%s", db_fget(i, COUNTRY));
}

static int
text_export_database(FILE * out, struct db_enumerator e)
{
	abook_list *emails, *em;
	int j;
	char *realname = get_real_name();
	char *style = opt_get_value_string("address_style");

	fprintf(out,
		"-----------------------------------------\n%s's address book\n"
		"-----------------------------------------\n\n\n",
		realname);
	free(realname);

	db_enumerate_items(e) {
		fprintf(out,
			"-----------------------------------------\n\n");
		fprintf(out, "%s", db_name_get(e.item));
		if(db_fget(e.item, NICK) && *db_fget(e.item, NICK))
			fprintf(out, "\n(%s)", db_fget(e.item, NICK));
		fprintf(out, "\n");

		if(*db_email_get(e.item)) {
			emails = csv_to_abook_list(db_email_get(e.item));

			fprintf(out, "\n");
			for(em = emails; em; em = em->next)
				fprintf(out, "%s\n", em->data);

			abook_list_free(&emails);
		}
		/* Print address */
		if(db_fget(e.item, ADDRESS)) {
			if(!safe_strcmp(style, "us"))	/* US like */
				text_write_address_us(out, e.item);
			else if(!safe_strcmp(style, "uk"))	/* UK like */
				text_write_address_uk(out, e.item);
			else	/* EU like */
				text_write_address_eu(out, e.item);

			fprintf(out, "\n");
			free(style);
		}

		if((db_fget(e.item, PHONE)) ||
			(db_fget(e.item, WORKPHONE)) ||
			(db_fget(e.item, FAX)) ||
			(db_fget(e.item, MOBILEPHONE))) {
			fprintf(out, "\n");
			for(j = PHONE; j <= MOBILEPHONE; j++)
				if(db_fget(e.item, j)) {
					fprintf(out, "%s: %s\n",
						safe_str(field_name(field_id(j))),
						db_fget(e.item, j));
				}
		}

		if(db_fget(e.item, URL))
			fprintf(out, "\n%s\n", db_fget(e.item, URL));
		if(db_fget(e.item, NOTES))
			fprintf(out, "\n%s\n", db_fget(e.item, NOTES));

		fprintf(out, "\n");
	}

	fprintf(out, "-----------------------------------------\n");

	return 0;
}


/*
 * Using filter helper
 */
#define FILTER_NAME text
#define FILTER_DESCRIPTION N_("plain text")
#define FILTER_EXPORT_FUNCTION text_export_database
#include "filter_helper.h"
