#ifndef _MISC_H
#define _MISC_H

/* List of strings */
typedef struct abook_list_t {
	char *data;
	struct abook_list_t *next;
} abook_list;

/* Buffer for parsing */
typedef struct {
	char *data, *ptr;
} abook_buffer;

/* Direction of list rotation */
enum rotate_dir {
	ROTATE_LEFT,
	ROTATE_RIGHT
};

/*
 * token parsing options
 */
#define TOKEN_ALLOC (1<<1) /* allocate memory for the token */
#define TOKEN_EQUAL (1<<2) /* left hand value of assignment */
#define TOKEN_COMMA (1<<3) /* comma is a separator */



/*
 * Misc functions
 */
char		*revstr(char *str);
char		*strupper(char *str);
char		*strlower(char *str);
char		*strtrim(char *);

char		*strdup_printf(const char *format, ... );
char		*strconcat(const char *str, ...);

int		safe_strcmp(const char *s1, const char *s2);
int		safe_strcoll(const char *s1, const char *s2);

char		*my_getcwd();

char		*getaline(FILE *f);

int		strwidth(const char *s);
int		bytes2width(const char *s, int width);

/*
 * List handling
 */
void		abook_list_append(abook_list **list, char *str);
void		abook_list_free(abook_list **list);
char		*abook_list_to_csv(abook_list *list);
abook_list	*csv_to_abook_list(char *str);
void		abook_list_rotate(abook_list **list, enum rotate_dir dir);
void		abook_list_replace(abook_list **list, int index, char *str);
#define	abook_list_delete(list, index) abook_list_replace(list, index, NULL)
char		*abook_list_get(abook_list *list, int index);
int		abook_list_count(abook_list *list);
void		abook_list_insert_sorted(abook_list **list, char *str);

/*
 * Parsing
 */
char *get_token(abook_buffer *b, int options);


/*
 * snprintf
 */
#ifdef HAVE_CONFIG_H
#	include "config.h"
#endif

#include <stdarg.h>

#ifndef HAVE_SNPRINTF
int snprintf (char *str, size_t count, const char *fmt, ...);
#endif
#ifndef HAVE_VSNPRINTF
int vsnprintf (char *str, size_t count, const char *fmt, va_list arg);
#endif

#endif



